/*
 *
 *  Copyright (C) 2012 Open-Xchange, Inc. All rights reserved.
 *
 *  This program is proprietary software and licensed to you under Open-Xchange
 *  Inc's Software License Agreement.
 *
 *  In some countries OX, OX Open-Xchange, open-xchange and OXtender as well as
 *  the corresponding Logos OX Open-Xchange and OX are registered trademarks of
 *  the Open-Xchange, Inc. group of companies.
 *
 */

package com.openexchange.documentconverter;

public enum Feature {
    DOCUMENTCONVERTER,

    SHAREPOINT_PDFCONVERSION, // you may pass a source mime type String parameter to the IManager.hasFeature method, in order to detect if
                             // the SharePoint service is supported for this kind of source document

    REMOTE_DOCUMENTCONVERTER
}
